==> 0.0.7.tar.gz: lib/woo_widget_connexion.dart <==
library woo_widget_connexion;

import 'package:flutter/material.dart';
import 'package:woo_widget_input/woo_widget_input.dart';

class InputConnexion extends StatefulWidget {
  String? Function(String?)? emailvalidator;
  dynamic Function(dynamic)? emailonChange;
  String? emaillabelText;
  String? emailinitialValue;
  String? emailmessageValidate;
  Widget? emaillabel;
  bool emailobscureText;
  bool emailpassword = false;
  bool emailemail = false;
  Widget? emailprefixIcon;
  Widget? emailsufixIcon;
  dynamic Function()? emailfuncSufixIcon;
  EdgeInsetsGeometry? emailmargin;
  EdgeInsetsGeometry? emailpadding;
  String? Function(String?)? pwsvalidator;
  dynamic Function(dynamic)? pwsonChange;
  dynamic Function(dynamic)? resultForm;
  String? pwslabelText;
  String? pwsinitialValue;
  String? pwsmessageValidate;
  Widget? pwslabel;
  bool pwsobscureText;
  bool pwspassword = false;
  bool pwsemail = false;
  Widget? pwsprefixIcon;
  Widget? pwssufixIcon;
  dynamic Function()? pwsfuncSufixIcon;
  EdgeInsetsGeometry? pwsmargin;
  EdgeInsetsGeometry? pwspadding;

  InputConnexion({
    Key? key,
    this.emailmargin,
    this.emailpadding,
    this.emailvalidator,
    this.emailonChange,
    this.emaillabelText,
    this.emailinitialValue,
    this.emaillabel,
    this.emailobscureText = false,
    this.emailprefixIcon,
    this.emailsufixIcon,
    this.emailfuncSufixIcon,
    this.emailpassword = false,
    this.emailmessageValidate,
    this.pwsmargin,
    this.pwspadding,
    this.pwsvalidator,
    this.pwsonChange,
    this.pwslabelText,
    this.pwsinitialValue,
    this.pwslabel,
    this.pwsobscureText = false,
    this.pwsprefixIcon,
    this.pwssufixIcon,
    this.pwsfuncSufixIcon,
    this.pwspassword = false,
    this.pwsmessageValidate,
    this.resultForm,
  }) : super(key: key);

  @override
  State<InputConnexion> createState() => _InputConnexionState();
}

class _InputConnexionState extends State<InputConnexion> {
  final RegExp emailRegex = RegExp(r"[a-z0-9\._-]+@[a-z0-9\._-]+\.[a-z]+");
  final GlobalKey<FormState> _formKey = GlobalKey<FormState>();

  String? inputEmailValue;
  String? inputPasswordValue;

  @override
  void dispose() {
    inputEmailValue = widget.emailinitialValue;
    inputPasswordValue = widget.pwsmessageValidate;
    super.dispose();
  }

  /// valider le contenue du input email
  String? validateEmail(String? value) {
    if (value == null || value.isEmpty || !emailRegex.hasMatch(value)) {
      widget.emailmessageValidate;
    }
    return null;
  }

  /// valider le contenue du input password
  String? validatePassword(String? value) {
    return value!.length < 6 ? widget.pwsmessageValidate : null;
  }

  Map<String, dynamic> createResultForm() {
    return {
      'email': inputEmailValue,
      'password': inputPasswordValue,
    };
  }

  @override
  Widget build(BuildContext context) {
    return Form(
      key: _formKey,
      child: Column(
        children: [
          InputCustom.email(
            initialValue: inputEmailValue,
            labelText: widget.emaillabelText,
            validator: (value) {
              return validateEmail(value);
            },
            onChange: (value) {
              setState(() => {
                    inputEmailValue = value,
                  });
            },
          ),
          InputCustom.password(
            initialValue: inputPasswordValue,
            labelText: widget.pwslabelText,
            validator: (value) {
              setState(() => {
                    validatePassword(value),
                  });
              return null;
            },
            onChange: (value) {
              setState(() => {
                    inputPasswordValue = value,
                  });
            },
          ),
          ElevatedButton(
            onPressed: () {
              final formValue = createResultForm();
              widget.resultForm!(formValue);
            },
            child: const Text('Valider'),
          ),
        ],
      ),
    );
  }
}

==> 0.0.8.tar.gz: lib/woo_widget_connexion.dart <==
library woo_widget_connexion;

import 'package:flutter/material.dart';
import 'package:woo_widget_input/woo_widget_input.dart';

class InputConnexion extends StatefulWidget {
  String? Function(String?)? emailvalidator;
  dynamic Function(dynamic)? emailonChange;
  String? emaillabelText;
  String? emailinitialValue;
  String? emailmessageValidate;
  Widget? emaillabel;
  bool emailobscureText;
  bool emailpassword = false;
  bool emailemail = false;
  Widget? emailprefixIcon;
  Widget? emailsufixIcon;
  dynamic Function()? emailfuncSufixIcon;
  EdgeInsetsGeometry? emailmargin;
  EdgeInsetsGeometry? emailpadding;
  String? Function(String?)? pwsvalidator;
  dynamic Function(dynamic)? pwsonChange;
  dynamic Function(dynamic)? resultForm;
  String? pwslabelText;
  String? pwsinitialValue;
  String? pwsmessageValidate;
  Widget? pwslabel;
  bool pwsobscureText;
  bool pwspassword = false;
  bool pwsemail = false;
  Widget? pwsprefixIcon;
  Widget? pwssufixIcon;
  dynamic Function()? pwsfuncSufixIcon;
  EdgeInsetsGeometry? pwsmargin;
  EdgeInsetsGeometry? pwspadding;

  InputConnexion({
    Key? key,
    this.emailmargin,
    this.emailpadding,
    this.emailvalidator,
    this.emailonChange,
    this.emaillabelText,
    this.emailinitialValue,
    this.emaillabel,
    this.emailobscureText = false,
    this.emailprefixIcon,
    this.emailsufixIcon,
    this.emailfuncSufixIcon,
    this.emailpassword = false,
    this.emailmessageValidate,
    this.pwsmargin,
    this.pwspadding,
    this.pwsvalidator,
    this.pwsonChange,
    this.pwslabelText,
    this.pwsinitialValue,
    this.pwslabel,
    this.pwsobscureText = false,
    this.pwsprefixIcon,
    this.pwssufixIcon,
    this.pwsfuncSufixIcon,
    this.pwspassword = false,
    this.pwsmessageValidate,
    this.resultForm,
  }) : super(key: key);

  @override
  State<InputConnexion> createState() => _InputConnexionState();
}

class _InputConnexionState extends State<InputConnexion> {
  final RegExp emailRegex = RegExp(r"[a-z0-9\._-]+@[a-z0-9\._-]+\.[a-z]+");
  final GlobalKey<FormState> _formKey = GlobalKey<FormState>();

  String? inputEmailValue;
  String? inputPasswordValue;

  @override
  void dispose() {
    inputEmailValue = widget.emailinitialValue;
    inputPasswordValue = widget.pwsmessageValidate;
    super.dispose();
  }

  /// valider le contenue du input email
  String? validateEmail(String? value) {
    return null;
  }

  /// valider le contenue du input password
  String? validatePassword(String? value) {
    return value!.length < 6 ? widget.pwsmessageValidate : null;
  }

  Map<String, dynamic> createResultForm() {
    return {
      'email': inputEmailValue,
      'password': inputPasswordValue,
    };
  }

  @override
  Widget build(BuildContext context) {
    return Form(
      key: _formKey,
      child: Column(
        children: [
          InputCustom.email(
            initialValue: inputEmailValue,
            labelText: widget.emaillabelText,
            validator: (value) {
              if (value == null ||
                  value.isEmpty ||
                  !emailRegex.hasMatch(value)) {
                widget.emailmessageValidate;
              }
              return null;
            },
            onChange: (value) {
              setState(() => {
                    inputEmailValue = value,
                  });
            },
          ),
          InputCustom.password(
            initialValue: inputPasswordValue,
            labelText: widget.pwslabelText,
            validator: (value) {
              setState(() => {
                    validatePassword(value),
                  });
              return null;
            },
            onChange: (value) {
              setState(() => {
                    inputPasswordValue = value,
                  });
            },
          ),
          ElevatedButton(
            onPressed: () {
              final formValue = createResultForm();
              widget.resultForm!(formValue);
            },
            child: const Text('Valider'),
          ),
        ],
      ),
    );
  }
}
